plot_binned_lat_long

plot_binned_lat_long(binned_data, width=10, height=6)

Visualize binned geographic coordinates on a heatmap.

This function takes the output of lat_long_binning and visualizes the spatial density of points using a heatmap, where each cell represents a latitude–longitude bin and the color intensity indicates the number of observations in that bin.

Parameters

Name Type Description Default
binned_data iterable of str Binned geographic coordinates formatted as “”, for example ”49.25-123.25”. Each element represents one observation. required
width int Width of the figure in inches (default is 10). 10
height int Height of the figure in inches (default is 6). 6

Returns

Name Type Description
matplotlib.axes.Axes The Matplotlib Axes object containing the heatmap.

Examples

>>> ax = plot_binned_lat_long(binned_data)
>>> plt.show()